@@ -13,6 +13,22 @@
 #  ../../COPYING
 
 
+################################################################################
+# GENERIC:                   DESCRIPTION
+#  returns                    Computes returns
+#  rowCumsums                 Computes row cumulated sums
+#  series                     Extracts series data
+#  series<-                   Assigns series data  
+#  coredata                   Extracts series data
+#  index                      deprecated
+#  index <-                   deprecated
+#  outlier                    Returns outliers
+#  timeSeries                 Returns timeSeries
+#  colCumsums                 Computes column cumulated sums
+#  colCummaxs                 Computes column cumulated maxima
+#  colCummins                 Computes column cumulated minima
+#  colCumprods                Computes column cumulated products
+#  colCumreturns              Computes column cumulated returns
 ################################################################################
 
 
@@ -35,6 +51,17 @@ setGeneric("series<-",
     function(x, value)
     standardGeneric("series<-"), package = "timeSeries")
 
+
+setGeneric("coredata", 
+    function(x) 
+    standardGeneric("coredata"), package = "timeSeries")
+    
+    
+setGeneric("coredata<-", 
+    function(x, value)
+    standardGeneric("coredata<-"), package = "timeSeries")
+
+
     
 ## setGeneric("index", function(x, ...)
 ##      standardGeneric("index"), package = "timeSeries")
